from typing import Type
from celery import Celery
from celery.backends.redis import RedisBackend

from pytest import mark
import pytest


from celery_redis_poll_backend import (
    PollingRedisBackend,
    PollingRedisClusterBackend,
    install_redis_poll_backend,
)


@mark.parametrize(
    "protocol, expected_backend",
    [
        ("redis", RedisBackend),
        ("redispoll", PollingRedisBackend),
        ("redisclusterpoll", PollingRedisClusterBackend),
    ],
)
def test_redis_cluster_backend_installation(
    protocol: str,
    expected_backend: Type,
):
    install_redis_poll_backend()

    # Initialize Celery app with RedisClusterBackend
    app = Celery(
        "test_app",
        broker="redis://localhost:6379/0",
        backend=f"{protocol}://localhost:6379/0",
    )

    # Check if the backend is set correctly
    assert isinstance(app.backend, expected_backend), (
        f"Backend is not set to {expected_backend}"
    )


if __name__ == "__main__":
    pytest.main()



from celery.backends.redis import RedisBackend
from typing import Any
import celery
from celery_redis_cluster_backend import RedisClusterBackend


class PollingRedisBackend(celery.backends.base.SyncBackendMixin, RedisBackend):
    """
    Disables pub/sub for getting task results and instead uses polling.
    """

    def _set(self, key: str, value: str) -> None:
        """
        Simply set value in Redis, do not publish.
        :param key:
        :param value:
        :return:
        """
        if self.expires:
            self.client.setex(key, self.expires, value)
        else:
            self.client.set(key, value)

    def on_task_call(self, *args: Any, **kwargs: Any) -> None:
        pass


class PollingRedisClusterBackend(PollingRedisBackend, RedisClusterBackend):
    """
    Same as PollingRedisBackend but with ReidsCluster for client.
    """

    pass
